@@ -2,7 +2,7 @@ package App::BorgRestore::Borg;
 use v5.14;
 use strictures 2;
 
-use App::BorgRestore::Helper;
+use App::BorgRestore::Helper qw(untaint);
 
 use autodie;
 use Date::Parse;
@@ -55,7 +55,14 @@ method borg_list() {
 	my @archives;
 	my $backup_prefix = $self->{backup_prefix};
 
-	if (Version::Compare::version_compare($self->{borg_version}, "1.1") >= 0) {
+	if (Version::Compare::version_compare($self->{borg_version}, "1.2") >= 0) {
+		$log->debug("Getting archive list via json");
+		run [qw(borg list --glob-archives), "$backup_prefix*", qw(--json), $self->{borg_repo}], '>', \my $output or die $log->error("borg list returned $?")."\n";
+		my $json = decode_json($output);
+		for my $archive (@{$json->{archives}}) {
+			push @archives, $archive->{archive};
+		}
+	} elsif (Version::Compare::version_compare($self->{borg_version}, "1.1") >= 0) {
 		$log->debug("Getting archive list via json");
 		run [qw(borg list --prefix), $backup_prefix, qw(--json), $self->{borg_repo}], '>', \my $output or die $log->error("borg list returned $?")."\n";
 		my $json = decode_json($output);
@@ -116,6 +123,7 @@ method borg_list_time() {
 
 method restore($components_to_strip, $archive_name, $path) {
 	$log->debugf("Restoring '%s' from archive %s, stripping %d components of the path", $path, $archive_name, $components_to_strip);
+	$archive_name = untaint($archive_name, qr(.*));
 	system(qw(borg extract -v --strip-components), $components_to_strip, $self->{borg_repo}."::".$archive_name, $path);
 }
 
